<?php

namespace Drupal\acquia_contenthub\Event;

use Acquia\ContentHubClient\CDFObject;
use Symfony\Component\EventDispatcher\Event;
use Drupal\Core\Entity\EntityInterface;

class ParseCDFEntityEvent extends Event {

  /**
   * The CDF Array to be parsed.
   *
   * @var CDFObject
   */
  protected $cdf;


  /**
   * The resulting entity.
   *
   * @var \Drupal\Core\Entity\EntityInterface
   */
  protected $entity;

  /**
   * ParseCDFEntityEvent constructor.
   *
   * @param CDFObject $cdf
   *   The CDF being parsed.
   */
  public function __construct(CDFObject $cdf) {
    $this->cdf = $cdf;
  }

  /**
   * Returns the CDF Array.
   *
   * @return \Acquia\ContentHubClient\CDFObject
   *   The CDF being parsed.
   */
  public function getCDF() {
    return $this->cdf;
  }

  /**
   * Obtains the parsed entity from the CDF.
   *
   * @return \Drupal\Core\Entity\EntityInterface
   *   The entity parsed from the CDF.
   */
  public function getEntity() {
    return $this->entity;
  }

  /**
   * Sets the parsed entity.
   *
   * @param \Drupal\Core\Entity\EntityInterface $entity
   *   The entity parsed from the CDF.
   */
  public function setEntity(EntityInterface $entity) {
    $this->entity = $entity;
  }
}
